# Multi-resolution Variational Inference

Multi-resolution Variational Inference (MrVI) is a package for analysis of sample-level heterogeneity in multi-site, multi-sample single-cell omics data. Built with [scvi-tools](https://scvi-tools.org).

---

To install, run:

```
pip install mrvi
```
